﻿<#

.SYNOPSIS

RemoveMaj.ps1

Utilitaire de suppression des mises à jour Windows KB5028166 et KB5028185

Désinstalle les deux mises à jour

Empêche la réinstallation automatique de ces mises à jour en utilisant "Hide-WindowsUpdate"
(voir "get-help Get-WindowsUpdate")


EXEMPLES :

RemoveMaj.ps1



#>

# par défaut (sans arguments) exécution locale
[CmdletBinding(DefaultParameterSetName = 'Local')]

# si distant, tous les arguments doivent être renseignés
param(
[Parameter(ParameterSetName='Distant',Mandatory=$true)] [string]$Machine #Nom de la machine distante
,[Parameter(ParameterSetName='Distant',Mandatory=$true)] [string]$IP #IP ou Nom de la machine distante
,[Parameter(ParameterSetName='Distant',Mandatory=$true)] [string]$Username #Utilisateur membre du groupe "Administrateurs" de la machine distante
,[Parameter(ParameterSetName='Distant',Mandatory=$true)] [string]$Password # mot de passe de l'utilisateur distant
,[Parameter(ParameterSetName='Aide')] [switch]$Help # mot de passe de l'utilisateur distant
)
#$PSCmdlet.ParameterSetName

$hlpmsg='PARAMÈTRES
    -Machine <String>
        Nom de la machine distante

    -IP <String>
        IP ou Nom de la machine distante

    -Username <String>
        Utilisateur membre du groupe "Administrateurs" de la machine distante

    -Password <String>
        mot de passe distant'
if ( $Help ) {
    Write-Output $hlpmsg
    exit
}

# Commandes
$cmd='Remove-WindowsUpdate  -KBArticleID KB5028166 -IgnoreReboot -Confirm:$false -Verbose
Hide-WindowsUpdate -KBArticleID KB5028166 -IgnoreReboot -Confirm:$false -Verbose
Remove-WindowsUpdate  -KBArticleID KB5028185 -IgnoreReboot -Confirm:$false -Verbose
Hide-WindowsUpdate -KBArticleID KB5028185 -IgnoreReboot -Confirm:$false -Verbose
Write-Output "Fin de la désinstallation et du blocage"
#pause
'

# conversion en base64
$commandBytes = [System.Text.Encoding]::Unicode.GetBytes($cmd)
$encodedCommand = [Convert]::ToBase64String($commandBytes)


if (! $Machine) {
    # local
    $isAdministrator = ([Security.Principal.WindowsPrincipal][Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)
    if ($isAdministrator) {
        Invoke-Expression $cmd
    }
    else {
        Start-Process -FilePath 'powershell' -ArgumentList "-ExecutionPolicy Bypass -NoProfile -EncodedCommand $encodedCommand" -Verb 'RunAs' -Wait
    }
}
else {
    # distant
    $secpw = ConvertTo-SecureString $Password -AsPlainText -Force
    $uname = $Machine+'\'+$Username
    $cred  = New-Object Management.Automation.PSCredential ($uname, $secpw)
    Invoke-Command -ComputerName $IP -Credential $cred -Scriptblock { Invoke-Expression $Using:cmd }

}


